mailr14729 - in /1.3/gui/analyses: auto_model_free.py auto_noe.py auto_rx_base.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on September 21, 2011 - 14:30:
Author: bugman
Date: Wed Sep 21 14:30:38 2011
New Revision: 14729

URL: http://svn.gna.org/viewcvs/relax?rev=14729&view=rev
Log:
Clicking on 'Execute relax' now also shifts the log window of the relax 
controller to the end.


Modified:
    1.3/gui/analyses/auto_model_free.py
    1.3/gui/analyses/auto_noe.py
    1.3/gui/analyses/auto_rx_base.py

Modified: 1.3/gui/analyses/auto_model_free.py
URL: 
http://svn.gna.org/viewcvs/relax/1.3/gui/analyses/auto_model_free.py?rev=14729&r1=14728&r2=14729&view=diff
==============================================================================
--- 1.3/gui/analyses/auto_model_free.py (original)
+++ 1.3/gui/analyses/auto_model_free.py Wed Sep 21 14:30:38 2011
@@ -561,9 +561,9 @@
             Missing_data(missing)
             return
 
-        # Display the relax controller.
-        if status.show_gui:
-            self.gui.show_controller(None)
+        # Display the relax controller, and go to the end of the log window.
+        self.gui.show_controller(None)
+        self.gui.controller.log_panel.on_goto_end(None)
 
         # Start the thread.
         self.thread = Execute_mf(self.gui, data, self.data_index)

Modified: 1.3/gui/analyses/auto_noe.py
URL: 
http://svn.gna.org/viewcvs/relax/1.3/gui/analyses/auto_noe.py?rev=14729&r1=14728&r2=14729&view=diff
==============================================================================
--- 1.3/gui/analyses/auto_noe.py (original)
+++ 1.3/gui/analyses/auto_noe.py Wed Sep 21 14:30:38 2011
@@ -257,9 +257,9 @@
             Missing_data(missing)
             return
 
-        # Display the relax controller.
-        if status.show_gui:
-            self.gui.show_controller(None)
+        # Display the relax controller, and go to the end of the log window.
+        self.gui.show_controller(None)
+        self.gui.controller.log_panel.on_goto_end(None)
 
         # Start the thread.
         self.thread = Execute_noe(self.gui, data, self.data_index)

Modified: 1.3/gui/analyses/auto_rx_base.py
URL: 
http://svn.gna.org/viewcvs/relax/1.3/gui/analyses/auto_rx_base.py?rev=14729&r1=14728&r2=14729&view=diff
==============================================================================
--- 1.3/gui/analyses/auto_rx_base.py (original)
+++ 1.3/gui/analyses/auto_rx_base.py Wed Sep 21 14:30:38 2011
@@ -273,9 +273,9 @@
             Missing_data(missing)
             return
 
-        # Display the relax controller.
-        if status.show_gui:
-            self.gui.show_controller(None)
+        # Display the relax controller, and go to the end of the log window.
+        self.gui.show_controller(None)
+        self.gui.controller.log_panel.on_goto_end(None)
 
         # Start the thread.
         self.thread = Execute_rx(self.gui, data, self.data_index)




Related Messages


Powered by MHonArc, Updated Wed Sep 21 14:40:02 2011